==> gcstar_1.1.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/CA/GCExport/GCExportHTML.pm <==
{
    package GCLang::CA::GCExport::GCExportHTML;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
        'WithJS' => 'Emprar Javascript',
       	'FileTemplate' => 'Plantilla:',
        'Preview' => 'Vista prèvia',
        'NoPreview' => 'Vista prèvia no disponible',
        'Title' => 'Títol de la pàgina',
        'InfoFile' => 'El llistat es troba a l\'arxiu: ',
        'InfoDir' => 'Les imatges es troben a: ',
        'HeightImg' => 'Alçada en píxels de les imatges a exportar: ',
        'OpenFileInBrowser' => 'Obrir el fitxer generat en el navegador web',
        'Note' => 'Llistat generat amb <a href="http://www.gcstar.org/">GCstar</a>',
        'InputTitle' => 'Introdueix el text a cercar',
        'SearchType1' => 'Només el Títol',
        'SearchType2' => 'Tota la informació',
        'SearchButton' => 'Cercar',    
        'SearchTitle' => 'Mostrar només les pel·lícules coincidents amb els criteris anteriors',
        'AllButton' => 'Totes',
        'AllTitle' => 'Mostrar totes les pel·lícules',
        'Expand' => 'Tots desplegats',
        'ExpandTitle' => 'Mostrar la informació de totes les pel·lícules',
        'Collapse' => 'Tots plegats',
        'CollapseTitle' => 'Ocultar la informació de totes les pel·lícules',
        'Borrowed' => 'Prestatari: ',
        'NotBorrowed' => 'Disponible',
        'Top' => 'Amunt',
     );
}

1;

==> gcstar_1.3.2.orig.tar.gz: gcstar/lib/gcstar/GCLang/CA/GCExport/GCExportHTML.pm <==
{
    package GCLang::CA::GCExport::GCExportHTML;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
        'ModelNotFound' => 'Fitxer de plantilla invàlid',
        'UseFile' => 'Utilitza el fitxer especificat abaix',
        'TemplateExternalFile' => 'Fitxer de plantilla',
        'WithJS' => 'Utilitza Javascript',
       	'FileTemplate' => 'Plantilla:',
        'Preview' => 'Vista prèvia',
        'NoPreview' => 'Vista prèvia no disponible',
        'Title' => 'Títol de la pàgina',
        'InfoFile' => 'El llistat de les pel·lícules es troba a l\'arxiu: ',
        'InfoDir' => 'Les imatges es troben a: ',
        'HeightImg' => 'Alçada en píxels de les imatges a exportar: ',
        'OpenFileInBrowser' => 'Obri el fitxer generat en el navegador web',
        'Note' => 'Llistat generat amb <a href="http://www.gcstar.org/">GCstar</a>',
        'InputTitle' => 'Introduíeu el text a cercar',
        'SearchType1' => 'Només el Títol',
        'SearchType2' => 'Tota la informació',
        'SearchButton' => 'Cerca',    
        'SearchTitle' => 'Mostra només les pel·lícules coincidents amb els criteris anteriors',
        'AllButton' => 'Totes',
        'AllTitle' => 'Mostra totes les pel·lícules',
        'Expand' => 'Tots desplegats',
        'ExpandTitle' => 'Mostrar la informació de totes les pel·lícules',
        'Collapse' => 'Tots plegats',
        'CollapseTitle' => 'Oculta la informació de totes les pel·lícules',
        'Borrowed' => 'Prestatari: ',
        'NotBorrowed' => 'Disponible',
        'Top' => 'Amunt',
        'Bottom' => 'Bottom',
     );
}

1;
